@@ -11,7 +11,7 @@ use DateTime::Duration;
 use Travel::Routing::DE::HAFAS::Utils;
 use Travel::Status::DE::HAFAS::Journey;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 Travel::Routing::DE::HAFAS::Connection::Section->mk_ro_accessors(
 	qw(type schep_dep rt_dep sched_arr rt_arr dep arr arr_delay dep_delay journey distance duration transfer_duration dep_loc arr_loc
@@ -153,6 +153,23 @@ sub messages {
 	return;
 }
 
+sub TO_JSON {
+	my ($self) = @_;
+
+	my $ret = { %{$self} };
+
+	for my $k ( keys %{$ret} ) {
+		if ( ref( $ret->{$k} ) eq 'DateTime' ) {
+			$ret->{$k} = $ret->{$k}->epoch;
+		}
+		if ( ref( $ret->{$k} ) eq 'DateTime::Duration' ) {
+			$ret->{$k} = [ $ret->{$k}->in_units( 'days', 'hours', 'minutes' ) ];
+		}
+	}
+
+	return $ret;
+}
+
 # }}}
 
 1;
@@ -181,7 +198,7 @@ Travel::Routing::DE::HAFAS::Connection::Section - A single trip between two stop
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 DESCRIPTION
 
